Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Secrets Manager.

Actions, resources, and condition keys for AWS Secrets Manager - Service Authorization Reference

# Actions, resources, and condition keys for AWS Secrets Manager

AWS Secrets Manager (service prefix: `secretsmanager` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by AWS Secrets Manager
- Resource types defined by AWS Secrets Manager
- Condition keys for AWS Secrets Manager

## Actions defined by AWS Secrets Manager

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CancelRotateSecret | Grants permission to cancel an in-progress secret rotation | Write | Secret* |  |
| secretsmanager:SecretId secretsmanager:resource/AllowRotationLambdaArn secretsmanager:ResourceTag/tag-key aws:ResourceTag/${TagKey} secretsmanager:SecretPrimaryRegion |
CreateSecret | Grants permission to create a secret that stores encrypted data that can be queried and rotated | Write | Secret* |  |
| secretsmanager:Name secretsmanager:Description secretsmanager:KmsKeyId aws:RequestTag/${TagKey} aws:ResourceTag/${TagKey} aws:TagKeys secretsmanager:ResourceTag/tag-key secretsmanager:AddReplicaRegions secretsmanager:ForceOverwriteReplicaSecret |
DeleteResourcePolicy | Grants permission to delete the resource policy attached to a secret | Permissions management | Secret* |  |
| secretsmanager:SecretId secretsmanager:resource/AllowRotationLambdaArn secretsmanager:ResourceTag/tag-key aws:ResourceTag/${TagKey} secretsmanager:SecretPrimaryRegion |
DeleteSecret | Grants permission to delete a secret | Write | Secret* |  |
| secretsmanager:SecretId secretsmanager:resource/AllowRotationLambdaArn secretsmanager:RecoveryWindowInDays secretsmanager:ForceDeleteWithoutRecovery secretsmanager:ResourceTag/tag-key aws:ResourceTag/${TagKey} secretsmanager:SecretPrimaryRegion |
DescribeSecret | Grants permission to retrieve the metadata about a secret, but not the encrypted data | Read | Secret* |  |
| secretsmanager:SecretId secretsmanager:resource/AllowRotationLambdaArn secretsmanager:ResourceTag/tag-key aws:ResourceTag/${TagKey} secretsmanager:SecretPrimaryRegion |
GetRandomPassword | Grants permission to generate a random string for use in password creation | Read |  |  |
GetResourcePolicy | Grants permission to get the resource policy attached to a secret | Read | Secret* |  |
| secretsmanager:SecretId secretsmanager:resource/AllowRotationLambdaArn secretsmanager:ResourceTag/tag-key aws:ResourceTag/${TagKey} secretsmanager:SecretPrimaryRegion |
GetSecretValue | Grants permission to retrieve and decrypt the encrypted data | Read | Secret* |  |
| secretsmanager:SecretId secretsmanager:VersionId secretsmanager:VersionStage secretsmanager:resource/AllowRotationLambdaArn secretsmanager:ResourceTag/tag-key aws:ResourceTag/${TagKey} secretsmanager:SecretPrimaryRegion |
ListSecretVersionIds | Grants permission to list the available versions of a secret | Read | Secret* |  |
| secretsmanager:SecretId secretsmanager:resource/AllowRotationLambdaArn secretsmanager:ResourceTag/tag-key aws:ResourceTag/${TagKey} secretsmanager:SecretPrimaryRegion |
ListSecrets | Grants permission to list the available secrets | List |  |  |
PutResourcePolicy | Grants permission to attach a resource policy to a secret | Permissions management | Secret* |  |
| secretsmanager:SecretId secretsmanager:resource/AllowRotationLambdaArn secretsmanager:ResourceTag/tag-key aws:ResourceTag/${TagKey} secretsmanager:BlockPublicPolicy secretsmanager:SecretPrimaryRegion |
PutSecretValue | Grants permission to create a new version of the secret with new encrypted data | Write | Secret* |  |
| secretsmanager:SecretId secretsmanager:resource/AllowRotationLambdaArn secretsmanager:ResourceTag/tag-key aws:ResourceTag/${TagKey} secretsmanager:SecretPrimaryRegion |
RemoveRegionsFromReplication | Grants permission to remove regions from replication | Write | Secret* |  |
| secretsmanager:SecretId secretsmanager:resource/AllowRotationLambdaArn secretsmanager:ResourceTag/tag-key aws:ResourceTag/${TagKey} secretsmanager:SecretPrimaryRegion |
ReplicateSecretToRegions | Grants permission to convert an existing secret to a multi-Region secret and begin replicating the secret to a list of new regions | Write | Secret* |  |
| secretsmanager:SecretId secretsmanager:resource/AllowRotationLambdaArn secretsmanager:ResourceTag/tag-key aws:ResourceTag/${TagKey} secretsmanager:SecretPrimaryRegion secretsmanager:AddReplicaRegions secretsmanager:ForceOverwriteReplicaSecret |
RestoreSecret | Grants permission to cancel deletion of a secret | Write | Secret* |  |
| secretsmanager:SecretId secretsmanager:resource/AllowRotationLambdaArn secretsmanager:ResourceTag/tag-key aws:ResourceTag/${TagKey} secretsmanager:SecretPrimaryRegion |
RotateSecret | Grants permission to start rotation of a secret | Write | Secret* |  |
| secretsmanager:SecretId secretsmanager:RotationLambdaARN secretsmanager:resource/AllowRotationLambdaArn secretsmanager:ResourceTag/tag-key aws:ResourceTag/${TagKey} secretsmanager:SecretPrimaryRegion secretsmanager:ModifyRotationRules secretsmanager:RotateImmediately |
StopReplicationToReplica | Grants permission to remove the secret from replication and promote the secret to a regional secret in the replica Region | Write | Secret* |  |
| secretsmanager:SecretId secretsmanager:resource/AllowRotationLambdaArn secretsmanager:ResourceTag/tag-key aws:ResourceTag/${TagKey} secretsmanager:SecretPrimaryRegion |
TagResource | Grants permission to add tags to a secret | Tagging | Secret* |  |
| secretsmanager:SecretId aws:RequestTag/${TagKey} aws:TagKeys secretsmanager:resource/AllowRotationLambdaArn secretsmanager:ResourceTag/tag-key aws:ResourceTag/${TagKey} secretsmanager:SecretPrimaryRegion |
UntagResource | Grants permission to remove tags from a secret | Tagging | Secret* |  |
| secretsmanager:SecretId aws:TagKeys secretsmanager:resource/AllowRotationLambdaArn secretsmanager:ResourceTag/tag-key aws:ResourceTag/${TagKey} secretsmanager:SecretPrimaryRegion |
UpdateSecret | Grants permission to update a secret with new metadata or with a new version of the encrypted data | Write | Secret* |  |
| secretsmanager:SecretId secretsmanager:Description secretsmanager:KmsKeyId secretsmanager:resource/AllowRotationLambdaArn secretsmanager:ResourceTag/tag-key aws:ResourceTag/${TagKey} secretsmanager:SecretPrimaryRegion |
UpdateSecretVersionStage | Grants permission to move a stage from one secret to another | Write | Secret* |  |
| secretsmanager:SecretId secretsmanager:VersionStage secretsmanager:resource/AllowRotationLambdaArn secretsmanager:ResourceTag/tag-key aws:ResourceTag/${TagKey} secretsmanager:SecretPrimaryRegion |
ValidateResourcePolicy | Grants permission to validate a resource policy before attaching policy | Permissions management | Secret* |  |
| secretsmanager:SecretId secretsmanager:resource/AllowRotationLambdaArn secretsmanager:ResourceTag/tag-key aws:ResourceTag/${TagKey} secretsmanager:SecretPrimaryRegion |

## Resource types defined by AWS Secrets Manager

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
Secret | `arn:$ { Partition}:secretsmanager:$ { Region}:$ { Account}:secret:$ { SecretId}` | aws:RequestTag/${TagKey} aws:ResourceTag/${TagKey} aws:TagKeys secretsmanager:ResourceTag/tag-key secretsmanager:resource/AllowRotationLambdaArn

## Condition keys for AWS Secrets Manager

AWS Secrets Manager defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by a key that is present in the request the user makes to the Secrets Manager service | String
aws:ResourceTag/${TagKey} | Filters access by the tags associated with the resource | String
aws:TagKeys | Filters access by the list of all the tag key names present in the request the user makes to the Secrets Manager service | String
secretsmanager:AddReplicaRegions | Filters access by the list of Regions in which to replicate the secret | ArrayOfString
secretsmanager:BlockPublicPolicy | Filters access by whether the resource policy blocks broad AWS account access | Bool
secretsmanager:Description | Filters access by the description text in the request | String
secretsmanager:ForceDeleteWithoutRecovery | Filters access by whether the secret is to be deleted immediately without any recovery window | Bool
secretsmanager:ForceOverwriteReplicaSecret | Filters access by whether to overwrite a secret with the same name in the destination Region | Bool
secretsmanager:KmsKeyId | Filters access by the ARN of the KMS key in the request | String
secretsmanager:ModifyRotationRules | Filters access by whether the rotation rules of the secret are to be modified | Bool
secretsmanager:Name | Filters access by the friendly name of the secret in the request | String
secretsmanager:RecoveryWindowInDays | Filters access by the number of days that Secrets Manager waits before it can delete the secret | Numeric
secretsmanager:ResourceTag/tag-key | Filters access by a tag key and value pair | String
secretsmanager:RotateImmediately | Filters access by whether the secret is to be rotated immediately | Bool
secretsmanager:RotationLambdaARN | Filters access by the ARN of the rotation Lambda function in the request | ARN
secretsmanager:SecretId | Filters access by the SecretID value in the request | ARN
secretsmanager:SecretPrimaryRegion | Filters access by primary region in which the secret is created | String
secretsmanager:VersionId | Filters access by the unique identifier of the version of the secret in the request | String
secretsmanager:VersionStage | Filters access by the list of version stages in the request | String
secretsmanager:resource/AllowRotationLambdaArn | Filters access by the ARN of the rotation Lambda function associated with the secret | ARN

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.